polyfemos.scripts.render_web_templates — polyfemos 0.3.29 documentation

# polyfemos.scripts.render_web_templates

A script to replace values in web templates with values defined in YAML configuration files.

copyright

  2019, University of Oulu, Sodankyla Geophysical Observatory

license

  GNU Lesser General Public License v3.0 or later (https://spdx.org/licenses/LGPL-3.0-or-later.html)

Public Functions

`polyfemos.scripts.render_web_templates.` `main`(argv=None)
  Parameters

    argv (list) – command line arguments